==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkTesting.java <==
// java wrapper for vtkTesting object
//

package vtk;
import vtk.*;

public class vtkTesting extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void FrontBufferOn_2();
  public void FrontBufferOn()
    { FrontBufferOn_2(); }

  private native void FrontBufferOff_3();
  public void FrontBufferOff()
    { FrontBufferOff_3(); }

  private native int GetFrontBuffer_4();
  public int GetFrontBuffer()
    { return GetFrontBuffer_4(); }

  private native void SetFrontBuffer_5(int id0);
  public void SetFrontBuffer(int id0)
    { SetFrontBuffer_5(id0); }

  private native int RegressionTest_6(double id0);
  public int RegressionTest(double id0)
    { return RegressionTest_6(id0); }

  private native int RegressionTest_7(String id0,double id1);
  public int RegressionTest(String id0,double id1)
    { return RegressionTest_7(id0,id1); }

  private native int RegressionTest_8(vtkAlgorithm id0,double id1);
  public int RegressionTest(vtkAlgorithm id0,double id1)
    { return RegressionTest_8(id0,id1); }

  private native int CompareAverageOfL2Norm_9(vtkDataSet id0,vtkDataSet id1,double id2);
  public int CompareAverageOfL2Norm(vtkDataSet id0,vtkDataSet id1,double id2)
    { return CompareAverageOfL2Norm_9(id0,id1,id2); }

  private native int CompareAverageOfL2Norm_10(vtkDataArray id0,vtkDataArray id1,double id2);
  public int CompareAverageOfL2Norm(vtkDataArray id0,vtkDataArray id1,double id2)
    { return CompareAverageOfL2Norm_10(id0,id1,id2); }

  private native void SetRenderWindow_11(vtkRenderWindow id0);
  public void SetRenderWindow(vtkRenderWindow id0)
    { SetRenderWindow_11(id0); }

  private native long GetRenderWindow_12();
  public vtkRenderWindow GetRenderWindow() {
    long temp = GetRenderWindow_12();

    if (temp == 0) return null;
    return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetValidImageFileName_13(String id0);
  public void SetValidImageFileName(String id0)
    { SetValidImageFileName_13(id0); }

  private native String GetValidImageFileName_14();
  public String GetValidImageFileName()
    { return GetValidImageFileName_14(); }

  private native double GetImageDifference_15();
  public double GetImageDifference()
    { return GetImageDifference_15(); }

  private native void AddArgument_16(String id0);
  public void AddArgument(String id0)
    { AddArgument_16(id0); }

  private native String GetArgument_17(String id0);
  public String GetArgument(String id0)
    { return GetArgument_17(id0); }

  private native void CleanArguments_18();
  public void CleanArguments()
    { CleanArguments_18(); }

  private native String GetDataRoot_19();
  public String GetDataRoot()
    { return GetDataRoot_19(); }

  private native void SetDataRoot_20(String id0);
  public void SetDataRoot(String id0)
    { SetDataRoot_20(id0); }

  private native String GetTempDirectory_21();
  public String GetTempDirectory()
    { return GetTempDirectory_21(); }

  private native void SetTempDirectory_22(String id0);
  public void SetTempDirectory(String id0)
    { SetTempDirectory_22(id0); }

  private native int IsValidImageSpecified_23();
  public int IsValidImageSpecified()
    { return IsValidImageSpecified_23(); }

  private native int IsInteractiveModeSpecified_24();
  public int IsInteractiveModeSpecified()
    { return IsInteractiveModeSpecified_24(); }

  private native int IsFlagSpecified_25(String id0);
  public int IsFlagSpecified(String id0)
    { return IsFlagSpecified_25(id0); }

  private native void SetBorderOffset_26(int id0);
  public void SetBorderOffset(int id0)
    { SetBorderOffset_26(id0); }

  private native int GetBorderOffset_27();
  public int GetBorderOffset()
    { return GetBorderOffset_27(); }

  private native void SetVerbose_28(int id0);
  public void SetVerbose(int id0)
    { SetVerbose_28(id0); }

  private native int GetVerbose_29();
  public int GetVerbose()
    { return GetVerbose_29(); }

  public vtkTesting() { super(); }

  public vtkTesting(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-1-aarch64.pkg.tar.xz: vtk/vtkTesting.java <==
// java wrapper for vtkTesting object
//

package vtk;
import vtk.*;

public class vtkTesting extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void FrontBufferOn_2();
  public void FrontBufferOn()
    { FrontBufferOn_2(); }

  private native void FrontBufferOff_3();
  public void FrontBufferOff()
    { FrontBufferOff_3(); }

  private native int GetFrontBuffer_4();
  public int GetFrontBuffer()
    { return GetFrontBuffer_4(); }

  private native void SetFrontBuffer_5(int id0);
  public void SetFrontBuffer(int id0)
    { SetFrontBuffer_5(id0); }

  private native int RegressionTest_6(double id0);
  public int RegressionTest(double id0)
    { return RegressionTest_6(id0); }

  private native int RegressionTest_7(String id0,double id1);
  public int RegressionTest(String id0,double id1)
    { return RegressionTest_7(id0,id1); }

  private native int RegressionTest_8(vtkAlgorithm id0,double id1);
  public int RegressionTest(vtkAlgorithm id0,double id1)
    { return RegressionTest_8(id0,id1); }

  private native int CompareAverageOfL2Norm_9(vtkDataSet id0,vtkDataSet id1,double id2);
  public int CompareAverageOfL2Norm(vtkDataSet id0,vtkDataSet id1,double id2)
    { return CompareAverageOfL2Norm_9(id0,id1,id2); }

  private native int CompareAverageOfL2Norm_10(vtkDataArray id0,vtkDataArray id1,double id2);
  public int CompareAverageOfL2Norm(vtkDataArray id0,vtkDataArray id1,double id2)
    { return CompareAverageOfL2Norm_10(id0,id1,id2); }

  private native void SetRenderWindow_11(vtkRenderWindow id0);
  public void SetRenderWindow(vtkRenderWindow id0)
    { SetRenderWindow_11(id0); }

  private native long GetRenderWindow_12();
  public vtkRenderWindow GetRenderWindow() {
    long temp = GetRenderWindow_12();

    if (temp == 0) return null;
    return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetValidImageFileName_13(String id0);
  public void SetValidImageFileName(String id0)
    { SetValidImageFileName_13(id0); }

  private native String GetValidImageFileName_14();
  public String GetValidImageFileName()
    { return GetValidImageFileName_14(); }

  private native double GetImageDifference_15();
  public double GetImageDifference()
    { return GetImageDifference_15(); }

  private native void AddArgument_16(String id0);
  public void AddArgument(String id0)
    { AddArgument_16(id0); }

  private native String GetArgument_17(String id0);
  public String GetArgument(String id0)
    { return GetArgument_17(id0); }

  private native void CleanArguments_18();
  public void CleanArguments()
    { CleanArguments_18(); }

  private native String GetDataRoot_19();
  public String GetDataRoot()
    { return GetDataRoot_19(); }

  private native void SetDataRoot_20(String id0);
  public void SetDataRoot(String id0)
    { SetDataRoot_20(id0); }

  private native String GetTempDirectory_21();
  public String GetTempDirectory()
    { return GetTempDirectory_21(); }

  private native void SetTempDirectory_22(String id0);
  public void SetTempDirectory(String id0)
    { SetTempDirectory_22(id0); }

  private native int IsValidImageSpecified_23();
  public int IsValidImageSpecified()
    { return IsValidImageSpecified_23(); }

  private native int IsInteractiveModeSpecified_24();
  public int IsInteractiveModeSpecified()
    { return IsInteractiveModeSpecified_24(); }

  private native int IsFlagSpecified_25(String id0);
  public int IsFlagSpecified(String id0)
    { return IsFlagSpecified_25(id0); }

  private native void SetBorderOffset_26(int id0);
  public void SetBorderOffset(int id0)
    { SetBorderOffset_26(id0); }

  private native int GetBorderOffset_27();
  public int GetBorderOffset()
    { return GetBorderOffset_27(); }

  private native void SetVerbose_28(int id0);
  public void SetVerbose(int id0)
    { SetVerbose_28(id0); }

  private native int GetVerbose_29();
  public int GetVerbose()
    { return GetVerbose_29(); }

  public vtkTesting() { super(); }

  public vtkTesting(long id) { super(id); }
  public native long   VTKInit();

}
